@@ -7,13 +7,13 @@
 
 #include <QTest>
 
-#include "kimaptest/fakeserver.h"
-#include "kimap/session.h"
 #include "kimap/listjob.h"
+#include "kimap/session.h"
+#include "kimaptest/fakeserver.h"
 
 #include <QTest>
 
-class FakeServerTest: public QObject
+class FakeServerTest : public QObject
 {
     Q_OBJECT
 
@@ -43,13 +43,12 @@ private Q_SLOTS:
 
         KIMAP::Session session(QStringLiteral("127.0.0.1"), 5989);
 
-        auto *job = new KIMAP::ListJob(&session);
+        auto job = new KIMAP::ListJob(&session);
         job->setIncludeUnsubscribed(true);
         QVERIFY(job->exec());
 
         fakeServer.quit();
     }
-
 };
 
 QTEST_GUILESS_MAIN(FakeServerTest)
