@@ -15,6 +15,8 @@
 #include <QDebug>
 
 #include <QFile>
+#include <QTcpServer>
+#include <QTcpSocket>
 #include <QTest>
 
 #include "imapstreamparser.h"
@@ -175,7 +177,7 @@ bool FakeServer::isAllScenarioDone() const
 {
     QMutexLocker locker(&m_mutex);
 
-    for (const QList<QByteArray> &scenario : qAsConst(m_scenarios)) {
+    for (const QList<QByteArray> &scenario : std::as_const(m_scenarios)) {
         if (!scenario.isEmpty()) {
             return false;
         }
