@@ -7,15 +7,13 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef FAKESERVER_H
-#define FAKESERVER_H
+#pragma once
 
 #include <QMutex>
 #include <QSsl>
-#include <QTcpServer>
-#include <QTcpSocket>
 #include <QThread>
-
+class QTcpSocket;
+class QTcpServer;
 namespace KIMAP
 {
 class ImapStreamParser;
@@ -226,4 +224,3 @@ private:
     QSsl::SslProtocol m_sslProtocol;
 };
 
-#endif
