@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_ACLJOBBASE_P_H
-#define KIMAP_ACLJOBBASE_P_H
+#pragma once
 
 #include "acljobbase.h"
 #include "job_p.h"
@@ -41,4 +40,3 @@ public:
 };
 }
 
-#endif
