@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_GETQUOTAROOTJOB_H
-#define KIMAP_GETQUOTAROOTJOB_H
+#pragma once
 
 #include "quotajobbase.h"
 
@@ -107,4 +106,3 @@ protected:
 
 }
 
-#endif
