@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_JOB_P_H
-#define KIMAP_JOB_P_H
+#pragma once
 
 #include "session.h"
 #include <QAbstractSocket>
@@ -49,4 +48,3 @@ public:
 
 }
 
-#endif
