@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_NAMESPACEJOB_H
-#define KIMAP_NAMESPACEJOB_H
+#pragma once
 
 #include "kimap_export.h"
 
@@ -42,4 +41,3 @@ protected:
 
 }
 
-#endif
