@@ -5,8 +5,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_SEARCHJOB_H
-#define KIMAP_SEARCHJOB_H
+#pragma once
 
 #include "kimap_export.h"
 
@@ -178,7 +177,7 @@ public:
     KIMAP_DEPRECATED void addSearchCriteria(const QByteArray &searchCriteria);
 
     /**
-     * Set the logic combining the search criterias.
+     * Set the logic combining the search criteria.
      * @param logic AND (the default), OR, NOT. See SearchLogics.
      * @deprecated since 4.13
      */
@@ -198,4 +197,3 @@ protected:
 
 }
 
-#endif
