@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_SESSIONUIPROXY_H
-#define KIMAP_SESSIONUIPROXY_H
+#pragma once
 
 #include "kimap_export.h"
 
@@ -17,12 +16,11 @@ class KSslErrorUiData;
 
 namespace KIMAP
 {
-
 /** @short Interface to display communication errors and wait for user feedback. */
 class KIMAP_EXPORT SessionUiProxy
 {
 public:
-    typedef QSharedPointer<SessionUiProxy> Ptr;
+    using Ptr = QSharedPointer<SessionUiProxy>;
 
     virtual ~SessionUiProxy();
     /**
@@ -53,4 +51,3 @@ public:
 
 }
 
-#endif
