@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_STOREJOB_H
-#define KIMAP_STOREJOB_H
+#pragma once
 
 #include "kimap_export.h"
 
@@ -57,4 +56,3 @@ protected:
 
 }
 
-#endif
