@@ -1,31 +1,30 @@
 /**
-  * This file is part of the KDE project
-  * SPDX-FileCopyrightText: 2009 Kevin Ottens <ervin@kde.org>
-  *
-  * SPDX-License-Identifier: LGPL-2.0-or-later
-  */
+ * This file is part of the KDE project
+ * SPDX-FileCopyrightText: 2009 Kevin Ottens <ervin@kde.org>
+ *
+ * SPDX-License-Identifier: LGPL-2.0-or-later
+ */
 
-#include <QDebug>
 #include <QCoreApplication>
-#include <QSignalSpy>
+#include <QDebug>
 
-#include "session.h"
 #include "capabilitiesjob.h"
+#include "closejob.h"
 #include "idlejob.h"
 #include "loginjob.h"
 #include "logoutjob.h"
 #include "selectjob.h"
-#include "closejob.h"
+#include "session.h"
 #include "sessionuiproxy.h"
 
 using namespace KIMAP;
 
-class UiProxy: public SessionUiProxy
+class UiProxy : public SessionUiProxy
 {
 public:
     bool ignoreSslError(const KSslErrorUiData &errorData) override
     {
-        Q_UNUSED(errorData);
+        Q_UNUSED(errorData)
         return true;
     }
 };
@@ -53,11 +52,11 @@ int main(int argc, char **argv)
 
     QCoreApplication app(argc, argv);
     Session session(server, port);
-    auto *proxy = new UiProxy();
+    auto proxy = new UiProxy();
     session.setUiProxy(UiProxy::Ptr(proxy));
 
     qDebug() << "Logging in...";
-    auto *login = new LoginJob(&session);
+    auto login = new LoginJob(&session);
     login->setUserName(user);
     login->setPassword(password);
     login->exec();
@@ -66,7 +65,7 @@ int main(int argc, char **argv)
     qDebug();
 
     qDebug() << "Asking for capabilities:";
-    auto *capabilities = new CapabilitiesJob(&session);
+    auto capabilities = new CapabilitiesJob(&session);
     capabilities->exec();
     Q_ASSERT_X(capabilities->error() == 0, "CapabilitiesJob", capabilities->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Authenticated);
@@ -76,7 +75,7 @@ int main(int argc, char **argv)
     Q_ASSERT(capabilities->capabilities().contains(QLatin1String("IDLE")));
 
     qDebug() << "Selecting INBOX:";
-    auto *select = new SelectJob(&session);
+    auto select = new SelectJob(&session);
     select->setMailBox(QStringLiteral("INBOX"));
     select->exec();
     Q_ASSERT_X(select->error() == 0, "SelectJob", select->errorString().toLocal8Bit().constData());
@@ -91,22 +90,19 @@ int main(int argc, char **argv)
     qDebug();
 
     qDebug() << "Start idling...";
-    auto *idle = new IdleJob(&session);
-    QObject::connect(idle, SIGNAL(mailBoxStats(KIMAP::IdleJob*,QString,int,int)),
-                     idle, SLOT(stop()));
+    auto idle = new IdleJob(&session);
+    QObject::connect(idle, SIGNAL(mailBoxStats(KIMAP::IdleJob *, QString, int, int)), idle, SLOT(stop()));
     idle->exec();
-    qDebug() << "Idling done for" << idle->lastMailBox()
-             << "message count:" << idle->lastMessageCount()
-             << "recent count:" << idle->lastRecentCount();
+    qDebug() << "Idling done for" << idle->lastMailBox() << "message count:" << idle->lastMessageCount() << "recent count:" << idle->lastRecentCount();
 
     qDebug() << "Closing INBOX:";
-    auto *close = new CloseJob(&session);
+    auto close = new CloseJob(&session);
     close->exec();
     Q_ASSERT(session.state() == Session::Authenticated);
     qDebug();
 
     qDebug() << "Logging out...";
-    auto *logout = new LogoutJob(&session);
+    auto logout = new LogoutJob(&session);
     logout->exec();
     Q_ASSERT_X(logout->error() == 0, "LogoutJob", logout->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Disconnected);
